<?php
if (!defined('ABSPATH')) {
    exit;
}

class Paynoloji_API
{
    private $app_id;
    private $app_secret;
    private $api_url;

    public function __construct($app_id, $app_secret)
    {
        $this->app_id = $app_id;
        $this->app_secret = $app_secret;
        $this->api_url = PAYNOLOGI_API_URL;
    }

    private function make_request($endpoint, $method, $data = null, $token = null)
    {
        $args = [
            'method' => $method,
            'headers' => [
                'Content-Type' => 'application/json',
            ],
        ];

        if ($token) {
            $args['headers']['Authorization'] = 'Bearer ' . $token;
        }

        if ($data) {
            $args['body'] = json_encode($data);
        }

        $response = wp_remote_request($this->api_url . $endpoint, $args);

        if (is_wp_error($response)) {
            return ['error' => $response->get_error_message()];
        }

        return json_decode(wp_remote_retrieve_body($response), true);
    }

    public function get_access_token()
    {
        $data = [
            'app_id' => $this->app_id,
            'app_secret' => $this->app_secret
        ];

        $response = $this->make_request('token', 'POST', $data);

        if (isset($response['code']) && $response['code'] == '200') {
            return $response['token'];
        }

        return ['error' => __('Access Token alınamadı', PAYNOLOGI_PLUGIN_TEXTDOMAIN)];
    }

    public function get_installments($bin_number, $amount)
    {
        $token = $this->get_access_token();

        if (isset($token['error'])) {
            return $token;
        }

        $data = [
            'card_number' => $bin_number,
            'amount' => $amount
        ];

        $response = $this->make_request('installments', 'POST', $data, $token);

        if (isset($response['code']) && $response['code'] == '200') {
            return $response['installments'];
        }

        return ['error' => __('Taksit bilgisi alınamadı ' . json_encode($response), PAYNOLOGI_PLUGIN_TEXTDOMAIN)];
    }

    public function create_payment_session($order)
    {
        $token = $this->get_access_token();

        if (isset($token['error'])) {
            return $token;
        }

        $unique_code = 'PAYN_' . $order->get_id() . '_' . uniqid();

        // Form verilerini hazırla
        $form_data = [
            'amount' => $order->get_total(),
            'currency' => $order->get_currency(),
            'other_code' => $unique_code,
            'return_url' => $order->get_checkout_order_received_url(),
            'callback_url' => home_url('/wc-api/paynoloji_callback'),
            'note' => sprintf("Site: %s Script: Wordpress Woocommerce ID: %s", get_site_url(), $order->get_id())
        ];

        // Token'ı form verilerine ekle
        $form_data['payment_token'] = $token;

        return $form_data;
    }
}
