<?php
if (!defined('ABSPATH')) {
    exit;
}

class Paynoloji_Loader
{

    public function __construct()
    {
        $this->check_dependencies();
        $this->init_hooks();
        $this->load_files();
    }

    private function check_dependencies()
    {
        if (!class_exists('WooCommerce')) {
            add_action('admin_notices', [$this, 'woocommerce_missing_notice']);
            return;
        }
    }

    public function woocommerce_missing_notice()
    {
        echo '<div class="error"><p><strong>Paynoloji Gateway</strong> çalışmak için WooCommerce eklentisine ihtiyaç duyar.</p></div>';
    }

    private function init_hooks()
    {
        add_action('before_woocommerce_init', [$this, 'declare_blocks_compatibility']);
        add_action('woocommerce_blocks_loaded', [$this, 'register_blocks_integration']);
        add_filter('woocommerce_payment_gateways', [$this, 'add_gateway']);
    }

    private function load_files()
    {
        require_once PAYNOLOGI_PLUGIN_DIR . 'includes/class-paynoloji-gateway.php';
        require_once PAYNOLOGI_PLUGIN_DIR . 'includes/class-paynoloji-api.php';
        require_once PAYNOLOGI_PLUGIN_DIR . 'includes/class-paynoloji-blocks.php';
    }

    public function declare_blocks_compatibility()
    {
        if (class_exists('\Automattic\WooCommerce\Utilities\FeaturesUtil')) {
            \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('cart_checkout_blocks', __FILE__, true);
        }
    }

    public function register_blocks_integration()
    {
        if (!class_exists('Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType')) {
            return;
        }

        add_action(
            'woocommerce_blocks_payment_method_type_registration',
            function ($registry) {
                $registry->register(new WC_Gateway_Paynoloji_Blocks());
            }
        );
    }

    public function add_gateway($methods)
    {
        $methods[] = 'WC_Gateway_Paynoloji';
        return $methods;
    }
}
