<?php
if (!defined('ABSPATH')) {
    exit;
}
?>
<div id="paynoloji-payment-form-wrapper">
    <form id="paynoloji_payment_form" action="<?php echo esc_url($payment_url); ?>" method="POST">
        <?php foreach ($form_data as $key => $value): ?>
            <input type="hidden" name="<?php echo esc_attr($key); ?>" value="<?php echo esc_attr($value); ?>" />
        <?php endforeach; ?>

        <div class="form-row">
            <label for="card_holder"><?php esc_html_e('Kart Sahibi', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></label>
            <input type="text" id="card_holder" name="card_holder" required
                placeholder="<?php esc_attr_e('Kart üzerindeki isim', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>"
                autocomplete="cc-name" />
        </div>

        <div class="form-row">
            <label for="card_number"><?php esc_html_e('Kart Numarası', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></label>
            <input type="text" id="card_number" name="card_number" required placeholder="XXXX XXXX XXXX XXXX"
                maxlength="19" autocomplete="cc-number" />
        </div>

        <div class="form-row card-details">
            <div class="expiry-date">
                <label for="exp_month"><?php esc_html_e('Son Kullanma Tarihi', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></label>
                <div class="expiry-inputs">
                    <select id="exp_month" name="exp_month" required>
                        <option value=""><?php esc_html_e('Ay', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></option>
                        <?php for ($i = 1; $i <= 12; $i++): ?>
                            <option value="<?php echo sprintf('%02d', $i); ?>"><?php echo sprintf('%02d', $i); ?></option>
                        <?php endfor; ?>
                    </select>
                    <select id="exp_year" name="exp_year" required>
                        <option value=""><?php esc_html_e('Yıl', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></option>
                        <?php
                        $current_year = date('Y');
                        for ($i = $current_year; $i <= $current_year + 10; $i++):
                        ?>
                            <option value="<?php echo substr($i, -2); ?>"><?php echo $i; ?></option>
                        <?php endfor; ?>
                    </select>
                </div>
            </div>
            <div class="cvv">
                <label for="cvv"><?php esc_html_e('CVV', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></label>
                <input type="text" id="cvv" name="cvv" required placeholder="XXX" maxlength="4" autocomplete="cc-csc" />
            </div>
        </div>

        <div class="form-row installments" style="display: none;">
            <label for="installment"><?php esc_html_e('Taksit Seçenekleri', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></label>
            <select id="installment" name="installment" required>
                <option value="1"><?php esc_html_e('Tek Çekim', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?></option>
            </select>
        </div>

        <div class="payment-buttons">
            <button type="submit" class="button alt">
                <?php esc_html_e('Ödemeyi Tamamla', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>
            </button>
            <a href="<?php echo esc_url(wc_get_cart_url()); ?>" class="button cancel">
                <?php esc_html_e('Sepete Dön', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>
            </a>
        </div>
    </form>
</div>

<style>
    #paynoloji-payment-form-wrapper {
        max-width: 600px;
        margin: 20px auto;
        padding: 20px;
        background: #fff;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
    }

    #paynoloji_payment_form .form-row {
        margin-bottom: 20px;
    }

    #paynoloji_payment_form label {
        display: block;
        margin-bottom: 8px;
        font-weight: 600;
        color: #2c3338;
    }

    #paynoloji_payment_form input[type="text"],
    #paynoloji_payment_form select {
        width: 96%;
        padding: 8px 12px;
        border: 1px solid #ddd;
        border-radius: 4px;
        font-size: 16px;
        line-height: 1.5;
    }

    #paynoloji_payment_form input[type="text"]:focus,
    #paynoloji_payment_form select:focus {
        border-color: #2271b1;
        box-shadow: 0 0 0 1px #2271b1;
        outline: none;
    }

    #paynoloji_payment_form .card-details {
        display: flex;
        gap: 20px;
    }

    #paynoloji_payment_form .expiry-date {
        flex: 2;
    }

    #paynoloji_payment_form .cvv {
        flex: 1;
    }

    #paynoloji_payment_form .expiry-inputs {
        display: flex;
        gap: 10px;
    }

    #paynoloji_payment_form .expiry-inputs select {
        flex: 1;
    }

    #paynoloji_payment_form .payment-buttons {
        display: flex;
        gap: 10px;
        margin-top: 30px;
    }

    #paynoloji_payment_form .button {
        flex: 1;
        padding: 12px 24px;
        border: none;
        border-radius: 4px;
        font-size: 16px;
        font-weight: 600;
        text-align: center;
        cursor: pointer;
        text-decoration: none;
    }

    #paynoloji_payment_form .button.alt {
        background-color: #2271b1;
        color: #fff;
    }

    #paynoloji_payment_form .button.alt:hover {
        background-color: #135e96;
    }

    #paynoloji_payment_form .button.cancel {
        background-color: #f0f0f1;
        color: #2c3338;
    }

    #paynoloji_payment_form .button.cancel:hover {
        background-color: #dcdcde;
    }

    @media (max-width: 480px) {
        #paynoloji_payment_form .card-details {
            flex-direction: column;
            gap: 15px;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        const form = document.getElementById('paynoloji_payment_form');
        const cardNumber = document.getElementById('card_number');
        const cvv = document.getElementById('cvv');
        const installmentsDiv = document.querySelector('.installments');
        const installmentSelect = document.getElementById('installment');
        let lastBin = '';
        const ajax_url = '<?php echo admin_url('admin-ajax.php'); ?>';

        // Taksit sorgulama fonksiyonu
        async function checkInstallments(bin) {
            try {
                const response = await fetch(ajax_url, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        action: 'paynoloji_get_installments',
                        bin: bin,
                        amount: '<?php echo esc_js($form_data['amount']); ?>',
                        nonce: '<?php echo wp_create_nonce('paynoloji-installments'); ?>'
                    })
                });

                const data = await response.json();
                console.log(data);
                if (data.success && data.data) {
                    installmentSelect.innerHTML = '';

                    // Tek çekim seçeneğini ekle
                    const singleOption = document.createElement('option');
                    singleOption.value = '1';
                    singleOption.textContent = '<?php esc_html_e('Tek Çekim', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>';
                    installmentSelect.appendChild(singleOption);

                    // Taksit seçeneklerini ekle
                    data.data.forEach(installment => {
                        if (installment.count > 1) {
                            const option = document.createElement('option');
                            option.value = installment.count;
                            option.textContent =
                                `${installment.count} Taksit - Aylık ${installment.monthly_amount} TL`;
                            installmentSelect.appendChild(option);
                        }
                    });

                    installmentsDiv.style.display = 'block';
                } else {
                    installmentsDiv.style.display = 'none';
                }
            } catch (error) {
                console.error('Taksit sorgulama hatası:', error);
                installmentsDiv.style.display = 'none';
            }
        }

        // Kart numarası değiştiğinde taksit sorgula
        cardNumber.addEventListener('input', function(e) {
            let value = e.target.value.replace(/\s+/g, '').replace(/[^0-9]/gi, '');
            let formattedValue = '';

            for (let i = 0; i < value.length; i++) {
                if (i > 0 && i % 4 === 0) {
                    formattedValue += ' ';
                }
                formattedValue += value[i];
            }

            e.target.value = formattedValue;

            // BIN numarası değiştiyse taksit sorgula
            const currentBin = value.substring(0, 6);
            if (currentBin.length === 6 && currentBin !== lastBin) {
                lastBin = currentBin;
                checkInstallments(currentBin);
            }
        });

        // CVV sadece rakam
        cvv.addEventListener('input', function(e) {
            e.target.value = e.target.value.replace(/[^0-9]/g, '');
        });

        // Form doğrulama
        form.addEventListener('submit', function(e) {
            const cardHolder = document.getElementById('card_holder').value.trim();
            const cardNum = cardNumber.value.replace(/\s+/g, '');
            const cvvNum = cvv.value;
            const month = document.getElementById('exp_month').value;
            const year = document.getElementById('exp_year').value;

            if (cardHolder.length < 5) {
                e.preventDefault();
                alert(
                    '<?php esc_html_e('Lütfen geçerli bir kart sahibi adı girin.', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>'
                );
                return;
            }

            if (cardNum.length !== 16) {
                e.preventDefault();
                alert(
                    '<?php esc_html_e('Lütfen geçerli bir kart numarası girin.', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>'
                );
                return;
            }

            if (cvvNum.length < 3) {
                e.preventDefault();
                alert(
                    '<?php esc_html_e('Lütfen geçerli bir CVV numarası girin.', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>'
                );
                return;
            }

            if (!month || !year) {
                e.preventDefault();
                alert(
                    '<?php esc_html_e('Lütfen son kullanma tarihini seçin.', PAYNOLOGI_PLUGIN_TEXTDOMAIN); ?>'
                );
                return;
            }
        });
    });
</script>